<!doctype html>
<html lang="ru">
<head>
    <meta charset="utf-8">
    <meta content="width=device-width, initial-scale=1, shrink-to-fit=no, user-scalable=no, viewport-fit=cover"
          name="viewport">
    <meta content="#FFFFFF" name="theme-color">
    <meta content="IE=Edge" http-equiv="X-UA-Compatible">

    <link href="/static/css/bootstrap.min.css" rel="stylesheet">
    <link href="/static/css/index.css" rel="stylesheet">
    <link href="/static/css/intlTelInput.min.css" rel="stylesheet">

    <title>b0mb3r 💣</title>
</head>
<body>

<span class="stop text-muted"></span>

<div id="block-ui">
    <div id="loader"></div>
</div>

<main>
    <h1 class="no-select">b0mb3r 💣</h1>
    <p class="lead">Доступно сервисов: <span class="badge badge-pill badge-danger no-select" id="serviceCount">{{ service_count }}</span>
    </p>
    <form id="main-form">
        <div class="form-row" style="margin-bottom: 5%">
            <div class="col">
                <label for="phone"></label>
                <input class="form-control" id="phone" name="phone" placeholder="912 345-67-89" required type="tel">
            </div>

            <div class="col">
                <label for="count"></label>
                <input class="form-control" id="count" min="1" name="number_of_cycles" placeholder="Количество повторов"
                       required type="number">
            </div>
        </div>

        <button class="btn btn-danger btn-lg" type="submit">Начать атаку</button>
    </form>
</main>

<footer class="mt-auto py-3 footer">
    <span class="text-muted">Made by <a href="https://github.com/crinny">crinny</a> with</span> <span class="heart" id="heart">&#10084;&#65039;</span>
</footer>

<script src="/static/js/intlTelInput.min.js"></script>
<script src="/static/js/progressbar.min.js"></script>
<script src="/static/js/index.js"></script>
</body>
</html>
