body, html {
    text-align: center;
    width: 100%;
    height: 100%;
    display: flex;
    justify-content: center;
    align-items: center
}

input[type=number]::-webkit-inner-spin-button, input[type=number]::-webkit-outer-spin-button {
    -webkit-appearance: none;
    margin: 0
}

input[type=number] {
    -moz-appearance: textfield
}

.no-select {
    -webkit-touch-callout: none;
    -webkit-user-select: none;
    -moz-user-select: none;
    -ms-user-select: none;
    user-select: none
}

.footer {
    background: #f5f5f5;
    position: fixed;
    height: 50px;
    bottom: 0;
    width: 100%
}

.heart {
    display: -moz-inline-stack;
    display: inline-block
}

.heart:hover {
    animation: heartbeat 1s infinite;
    animation-timing-function: linear
}

#loader {
    width: 50px;
    height: 50px;
    left: 50%;
    top: 50%;
    margin: -15px 0 0 -15px;
    position: absolute;
    z-index: 1080;
    opacity: 0;
}

#block-ui {
    width: 100%;
    height: 100%;
    display: none;
    position: absolute;
    z-index: 15;
    cursor: wait;
}

.iti__flag {
    background-image: url(/static/img/flags.png)
}

.stop:before {
  content: "✕";
}

.stop {
  z-index: 16;
  display: none;
  position: absolute;
  top: 10px;
  right: 10px;
  line-height: 1;
  cursor: pointer;
  font-size: 1.8rem;
}

@keyframes heartbeat {
    0% {
        transform: scale(.75)
    }
    20% {
        transform: scale(1)
    }
    40% {
        transform: scale(.75)
    }
    60% {
        transform: scale(1)
    }
    80% {
        transform: scale(.75)
    }
    100% {
        transform: scale(.75)
    }
}

@keyframes pulsate {
    0% {
        transform: scale(.1);
        opacity: 0
    }
    50% {
        opacity: 1
    }
    100% {
        transform: scale(1.2);
        opacity: 0
    }
}

@keyframes blur {
    0% {
        -webkit-filter: blur(0);
        filter: blur(0)
    }
    100% {
        -webkit-filter: blur(3px);
        filter: blur(3px)
    }
}

@keyframes fadeIn {
    0% {
        opacity: 0;
    }
    100% {
        opacity: 1;
    }
}

@keyframes fadeOut {
    0% {
        opacity: 1;
    }
    100% {
        opacity: 0;
    }
}

@media screen and (min-width: 250px) and (max-width: 768px) {
    #main-form {
        margin-right: 6%;
        margin-left: 6%
    }
}

@media screen and (min-width: 768px) and (max-width: 1200px) {
    .stop {
        font-size: 2rem;
    }
}

@media screen and (min-width: 1300px) and (max-width: 1920px) {
    .stop {
        font-size: 2.3rem;
    }
}

@media (-webkit-min-device-pixel-ratio: 2),(min-resolution: 192dpi) {
    .iti__flag {
        background-image: url(/static/img/flags@2x.png)
    }
}
